/*
 * Copyright 2020 Red Hat
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.apicurio.registry.storage.impl.jpa.entity;

import io.apicurio.registry.storage.impl.jpa.search.ArtifactSearchResult;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.ToString;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import javax.persistence.SqlResultSetMapping;
import javax.persistence.ConstructorResult;
import javax.persistence.ColumnResult;

@Entity
@Table(
        name = "meta",
        uniqueConstraints = @UniqueConstraint(columnNames = {"artifact_id", "version", "key"}),
        indexes = @Index(columnList = "artifact_id, version, key", unique = true)
)
@NoArgsConstructor
@AllArgsConstructor
@Builder
@Getter
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
@ToString
@SqlResultSetMapping(name = "ArtifactSearchResultMapping", classes = @ConstructorResult(targetClass = ArtifactSearchResult.class, columns = {
        @ColumnResult(name = "id"), @ColumnResult(name = "name"), @ColumnResult(name = "description"),
        @ColumnResult(name = "createdOn"), @ColumnResult(name = "createdBy"), @ColumnResult(name = "type"),
        @ColumnResult(name = "labels"), @ColumnResult(name = "state"), @ColumnResult(name = "modifiedOn"),
        @ColumnResult(name = "modifiedBy") }))
public class MetaData {

    @Id
    @GeneratedValue
    @Column(name = "id", updatable = false, nullable = false)
    @EqualsAndHashCode.Include
    private Long id;

    @Column(name = "artifact_id", updatable = false, nullable = false)
    @EqualsAndHashCode.Include
    private String artifactId;

    @Column(name = "version", updatable = false)
    @EqualsAndHashCode.Include
    private Long version;

    @Column(name = "key", updatable = false, nullable = false)
    @EqualsAndHashCode.Include
    private String key;

    @Column(name = "value", nullable = false)
    @Setter
    private String value;
}
